#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 io-storage
version:              0.3
visibility:           public
id:                   io-storage-0.3-4sb37R6CbPdBClCIs8CfjR
key:                  io-storage-0.3-4sb37R6CbPdBClCIs8CfjR
license:              BSD-3-Clause
copyright:            (c) 2009 Will Donnelly
maintainer:           Will Donnelly <will.donnelly@gmail.com>
author:               Will Donnelly
stability:            alpha
homepage:             http://github.com/willdonnelly/io-storage
synopsis:             A key-value store in the IO monad.
description:
    This library allows an application to extend the '\''global state'\''
    hidden inside the IO monad with semi-arbitrary data. Data is
    required to be '\''Typeable'\''. The library provides an essentially
    unbounded number of key-value stores indexed by strings, with
    each key within the stores also being a string.

category:             Database, Data, System
abi:                  ae2398b2cf5f2ca3b7fd3c92f2bdd117
exposed:              True
exposed-modules:      System.IO.Storage
import-dirs:          /usr/lib/ghc-9.6.6/site-local/io-storage-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/io-storage-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/io-storage-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-io-storage
hs-libraries:         HSio-storage-0.3-4sb37R6CbPdBClCIs8CfjR
depends:              base-4.18.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-io-storage/html/io-storage.haddock
haddock-html:         /usr/share/doc/haskell-io-storage/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

